package de.fraunhofer.iem.dataprovider.sarif

import de.fraunhofer.iem.dataprovider.toolResult.*
import kotlinx.serialization.decodeFromString
import kotlinx.serialization.json.Json
import java.io.IOException
import java.nio.file.Path

fun Rule.asDbObject(): RuleDb {
    return RuleDb(
        ruleId = this.id,
        name = this.name,
        shortDescription = this.shortDescription.text,
        helpUri = this.helpUri
    )
}

fun Tool.asDbObject(): ToolDb {
    return ToolDb(
        fullName = this.driver.fullName,
        name = this.driver.name,
        rules = this.driver.rules.map { it.asDbObject() },
        downloadUri = this.driver.downloadUri,
        guid = this.driver.guid,
        informationUri = this.driver.informationUri,
        language = this.driver.language,
        organization = this.driver.organization,
        semanticVersion = this.driver.semanticVersion,
        version = this.driver.version,
    )
}

fun Location.asDbObject(): ResultLocationDb {
    return ResultLocationDb(
        artifactLocationUri = this.physicalLocation.artifactLocation.uri,
        endColumn = this.physicalLocation.region.endColumn,
        endLine = this.physicalLocation.region.endLine,
        startColumn = this.physicalLocation.region.startColumn,
        startLine = this.physicalLocation.region.startLine,
    )
}

fun Result.asDbObject(): ToolResultDb {
    return ToolResultDb(
        level = this.level,
        locations = this.locations.map { it.asDbObject() },
        message = this.message.text,
        ruleId = this.ruleId
    )
}

fun Sarif.asDbObject(): List<ToolResultsDb> {


    return this.runs.map { run ->
        ToolResultsDb(
            results = run.results.map { it.asDbObject() },
            tool = run.tool.asDbObject(),
        )
    }
}

fun getSarifFromFilePath(resultPath: Path): Sarif {
    val resFile = resultPath.toFile()
    if (resFile.exists()) {
        val resString = resFile.readText()
        val json = Json { ignoreUnknownKeys = true }
        return json.decodeFromString<Sarif>(resString)
    }

    throw IOException("File not found / Path is no file.")
}
