package de.fraunhofer.iem.dataprovider.taskManager.tasks

import de.fraunhofer.iem.dataprovider.sarif.getSarifFromFilePath
import de.fraunhofer.iem.dataprovider.taskManager.Event
import de.fraunhofer.iem.dataprovider.taskManager.ProcessTaskDone
import org.springframework.core.io.ClassPathResource
import org.springframework.core.io.Resource
import java.nio.file.Paths


class DetektTask(projectPath: String, outputPath: String, override val responseChannel: suspend (task: Event) -> Unit) :
    ProcessTask() {

    private val resource: Resource = ClassPathResource("scripts/detekt.sh")
    override val flags: Array<String> = arrayOf(resource.file.absolutePath, projectPath, outputPath)

    override val execPath: String = "/bin/sh"

    private val resultPath = Paths.get(outputPath, "detekt", "report.sarif")
    override suspend fun handleProcessReturn(p: Process) {
        logger.info(resource.toString())

        val returnMessage = "Odc finished with exit code ${p.exitValue()}"
//        val output = String(p.inputStream.readAllBytes())
//        logger.info("Process output $output")

        val sarifResult = getSarifFromFilePath(resultPath)

        sarifResult.runs.forEach {
            it.results.forEach {
                logger.info("run in sarif result message: ${it.message}")
            }
        }

        responseChannel(ProcessTaskDone(taskID, returnMessage))
    }
}